
/////////////////////////////////////////////////////////////////////////
// G4Tutorial:
//
// PhysicsEMElectronStandard.hh
// 
// Assembling electromagnetic physics processes for electrons.
// 
// The considered processes are G4MultipleScattering, 4eIonisation
// and G4eBremsstrahlung 
//
/////////////////////////////////////////////////////////////////////////


#ifndef PHYSICSEMELECTRONSTANDARD_HH
#define PHYSICSEMELECTRONSTANDARD_HH

#include "G4VPhysicsConstructor.hh"
#include "globals.hh"


// G4VPhysicsConstructor is the abstract base class for physics constructors:

class PhysicsEMElectronStandard : public G4VPhysicsConstructor {

 public: 
   PhysicsEMElectronStandard(const G4String& name = "Electron-Standard"); 
   virtual ~PhysicsEMElectronStandard();
  
 

   // G4VPhysicsConstructor has two pure virtual methods which must be 
   // implemented by the user: ConstructParticle and ConstructProcess.
   // Since only physics processes are dealt with here, ConstructParticle
   // is irrelevant and performs no action. ConstructProcess is used to
   // instantiate all physics processes relevant for the considered particle
   // and type of interaction.
   void ConstructParticle() { };
   void ConstructProcess();
};

#endif // PHYSICSEMELECTRONSTANDARD_HH

