
/////////////////////////////////////////////////////////////////////////
// G4Tutorial:
//
// PhysicsEMPhotonStandard.cc
// 
// Assembling electromagnetic physics processes for photons.
// 
// The considered processes are G4PhotoElectricEffect, G4ComptonScattering
// and G4GammaConversion 
//
/////////////////////////////////////////////////////////////////////////


#include "PhysicsEMPhotonStandard.hh"
#include "G4ProcessManager.hh"
#include "G4ParticleDefinition.hh"
#include "G4Gamma.hh"
#include "G4ComptonScattering.hh"
#include "G4GammaConversion.hh"
#include "G4PhotoElectricEffect.hh"
#include "G4StepLimiter.hh"


PhysicsEMPhotonStandard::PhysicsEMPhotonStandard(const G4String& name): 
   G4VPhysicsConstructor(name) {
 
  // Information about physics processes is printed:
  G4cout << "ELECTROMAGNETIC PROCESS(ES): G4PhotoElectricEffect (photon)" 
         << G4endl
         << "                             G4ComptonScattering (photon)" 
         << G4endl
         << "                             G4GammaConversion (photon)" 
         << G4endl
         << "APPLIED MODEL(S): -" 
         << G4endl;
}


PhysicsEMPhotonStandard::~PhysicsEMPhotonStandard() { 

}


void PhysicsEMPhotonStandard::ConstructProcess() {

  // **************
  // *** Photon ***
  // **************
   
  // The considered physics processes are instantiated:
  G4PhotoElectricEffect* photPhotoElectricProcess = 
                                            new G4PhotoElectricEffect();
  G4ComptonScattering* photComptonProcess = new G4ComptonScattering;
  G4GammaConversion* photGammaConvProcess = new G4GammaConversion;

  // The step limiter process is instantiated:
  G4StepLimiter* photStepLimiter = new G4StepLimiter();

  // Finally, the processes are added to the particles' process manager:
  G4ParticleDefinition* particle = G4Gamma::Gamma(); 
  G4ProcessManager* processManager = particle -> GetProcessManager();
  processManager -> AddDiscreteProcess(photPhotoElectricProcess);
  processManager -> AddDiscreteProcess(photComptonProcess);
  processManager -> AddDiscreteProcess(photGammaConvProcess);
  processManager -> AddDiscreteProcess(photStepLimiter);
}
